@@ -1,7 +1,9 @@
 from .video_reader import VideoReader
 from .video_data import VideoData
+from .video_writer import VideoWriter
 
 __all__ = [
     "VideoReader",
+    "VideoWriter",
     "VideoData"
 ]
