@@ -1,4 +1,4 @@
-from .component import Component, Variable, ProgressBar, Image, Logger
+from .component import Component, Variable, ProgressBar, Image, Logger, LineChart
 from .view import View
 from .server import Server
 
@@ -8,6 +8,7 @@ __all__ = [
     "ProgressBar",
     "Image",
     "Logger",
+    "LineChart",
     "View",
     "Server"
 ]
